import configparser
import importlib_resources as res

__version__ = '1.2.0'

cfg = configparser.ConfigParser()
with res.path('KRNG', 'config.cfg') as cfgFile:
    cfg.read(str(cfgFile))
URL = cfg['KRNG']['url']



import pafy
from cv2 import VideoCapture
import numpy as np
import hashlib as hl
import random

from KRNG import URL

def KRN():
    '''Get a Kitten Based Random Number'''
    vPafy = pafy.new(url=URL)
    play = vPafy.getbest()

    cap = VideoCapture(play.url)

    ret, frame = cap.read()
    number = int(hl.sha256(frame.data.tobytes()).hexdigest(), 16)
    cap.release()
    return number

def KPRNG() -> random.Random:
    '''Get a Kitten Seeded PRNG'''

    seed = KRN()
    rand = random.Random(seed)

    return rand


import pathlib
from setuptools import setup, find_packages

root = pathlib.Path(__file__).parent

readme = (root / 'README.md').read_text()

setup(
    name='kitten-rng',
    version='1.2.0',
    description='''an rng that generates its numbers based off of a
        kitten livestream''',
    long_description=readme,
    long_description_content_type='text/markdown',
    url='https://github.com/SuniTheFish/Kitten-RNG',
    author='Benjamin Hinchliff',
    author_email='benjamin.hinchliff@gmail.com',
    license='MIT',
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.8',
    ],
    packages=find_packages(exclude=('KRNG_env',)),
    include_package_data=True,
    install_requires=[
        'opencv-python', 'pafy', 'youtube_dl', 'importlib-resources'
    ],
    entry_points={
        'console_scripts': [
            'realpython=reader.__main__:main',
        ],
    },
)

